# coding: utf-8

"""
    external/v1/external_session_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""


import pprint
import re  # noqa: F401
from typing import TYPE_CHECKING

import six

from grid.openapi.configuration import Configuration

if TYPE_CHECKING:
    from datetime import datetime
    from grid.openapi.models import *

class V1DatastoreFSxSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'storage_capacity_gib': 'int',
        'storage_throughput_mb_s_tib': 'int'
    }

    attribute_map = {
        'storage_capacity_gib': 'storageCapacityGib',
        'storage_throughput_mb_s_tib': 'storageThroughputMbSTib'
    }

    def __init__(self, storage_capacity_gib: 'int' = None, storage_throughput_mb_s_tib: 'int' = None, _configuration=None):  # noqa: E501
        """V1DatastoreFSxSpec - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._storage_capacity_gib = None
        self._storage_throughput_mb_s_tib = None
        self.discriminator = None

        if storage_capacity_gib is not None:
            self.storage_capacity_gib = storage_capacity_gib
        if storage_throughput_mb_s_tib is not None:
            self.storage_throughput_mb_s_tib = storage_throughput_mb_s_tib

    @property
    def storage_capacity_gib(self) -> 'int':
        """Gets the storage_capacity_gib of this V1DatastoreFSxSpec.  # noqa: E501


        :return: The storage_capacity_gib of this V1DatastoreFSxSpec.  # noqa: E501
        :rtype: int
        """
        return self._storage_capacity_gib

    @storage_capacity_gib.setter
    def storage_capacity_gib(self, storage_capacity_gib: 'int'):
        """Sets the storage_capacity_gib of this V1DatastoreFSxSpec.


        :param storage_capacity_gib: The storage_capacity_gib of this V1DatastoreFSxSpec.  # noqa: E501
        :type: int
        """

        self._storage_capacity_gib = storage_capacity_gib

    @property
    def storage_throughput_mb_s_tib(self) -> 'int':
        """Gets the storage_throughput_mb_s_tib of this V1DatastoreFSxSpec.  # noqa: E501


        :return: The storage_throughput_mb_s_tib of this V1DatastoreFSxSpec.  # noqa: E501
        :rtype: int
        """
        return self._storage_throughput_mb_s_tib

    @storage_throughput_mb_s_tib.setter
    def storage_throughput_mb_s_tib(self, storage_throughput_mb_s_tib: 'int'):
        """Sets the storage_throughput_mb_s_tib of this V1DatastoreFSxSpec.


        :param storage_throughput_mb_s_tib: The storage_throughput_mb_s_tib of this V1DatastoreFSxSpec.  # noqa: E501
        :type: int
        """

        self._storage_throughput_mb_s_tib = storage_throughput_mb_s_tib

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1DatastoreFSxSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1DatastoreFSxSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1DatastoreFSxSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other: 'V1DatastoreFSxSpec') -> bool:
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1DatastoreFSxSpec):
            return True

        return self.to_dict() != other.to_dict()
